Django Media Tree
*****************

Django Media Tree is a Django app for managing your website's media files in a
folder tree, and using them in your own applications.

Key features
============

* Enables you to organize all of your site media in nested folders.
* Supports various media types (images, audio, video, archives etc).
* Extension system, enabling you to easily add special processing for different
  media types and extend the admin interface.
* Speedy AJAX-enhanced admin interface with drag & drop and dynamic resizing.
* Upload queue with progress indicators (using Fine Uploader).
* Add metadata to all media to improve accessibility of your web sites.
* Integration with `Django CMS <http://www.django-cms.org>`_. Plugins include:
  image, slideshow, gallery, download list -- create your own! 

Full documentation
==================

http://readthedocs.org/docs/django-media-tree/